@@ -101,6 +101,7 @@ class User(MojoSecrets, AbstractBaseUser, MojoModel):
         SEARCH_FIELDS = ["username", "email", "display_name"]
         VIEW_PERMS = ["view_users", "manage_users", "owner"]
         SAVE_PERMS = ["manage_users", "owner"]
+        OWNER_FIELD = "self"
         LIST_DEFAULT_FILTERS = {
             "is_active": True
         }
@@ -483,13 +484,36 @@ class User(MojoSecrets, AbstractBaseUser, MojoModel):
         self.send_invite()
 
     def push_notification(self, title=None, body=None, data=None,
-                          category="general", action_url=None,
-                          devices=None, user_ids=None, delay=None):
-        from mojo.apps.account.services.push import send_direct_notification
-        send_direct_notification(
-            self, title=title, body=body, data=data, category=category,
-            action_url=action_url,
-            devices=devices, user_ids=user_ids, delay=delay)
+                          category="general", action_url=None):
+        """
+        Send push notification to all user's active devices.
+        Simple - just loops through devices and calls device.send().
+
+        Args:
+            title: Notification title (optional for silent notifications)
+            body: Notification body (optional for silent notifications)
+            data: Custom data payload dict
+            category: Notification category
+            action_url: URL to open when notification is tapped
+
+        Returns:
+            List of NotificationDelivery objects
+        """
+        devices = self.registered_devices.filter(is_active=True, push_enabled=True)
+
+        deliveries = []
+        for device in devices:
+            delivery = device.send(
+                title=title,
+                body=body,
+                data=data,
+                category=category,
+                action_url=action_url
+            )
+            if delivery:
+                deliveries.append(delivery)
+
+        return deliveries
 
     def send_invite(self, **kwargs):
         from mojo.apps.account.utils import tokens
@@ -682,6 +706,21 @@ class User(MojoSecrets, AbstractBaseUser, MojoModel):
         self.metadata = meta
         self.save(update_fields=["metadata"])
 
+    def on_realtime_can_subscribe(self, topic):
+        if topic.startswith("group:"):
+            from .group import Group
+            if self.has_permission(["view_groups", "manage_groups"]):
+                return True
+            group = Group.objects.filter(pk=int(topic.split(":")[1])).last()
+            if group is None:
+                return False
+            return group.get_member_for_user(self) is not None
+        if topic == f"user:{self.id}":
+            return True
+        if topic == "general_announcements":
+            return True
+        return False
+
     @classmethod
     def validate_jwt(cls, token, request=None):
         token_manager = JWToken()
